HomebrewArtifact class final

One downloadable Homebrew artifact.

Constructors

HomebrewArtifact({required String platform, required String architecture, required String url, required String sha256, required String fileName})
const

Properties

architecture String
final
fileName String
final
hashCode int
The hash code for this object.
no setterinherited
platform String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sha256 String
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited