HomebrewFormulaConfig class final

Product metadata for a generated Homebrew Formula.

Constructors

HomebrewFormulaConfig({required String className, required String description, required String homepage, required String version, required String executableName, PayloadKind payload = PayloadKind.executable, bool versioned = false})
const

Properties

className String
final
description String
final
executableName String
final
hashCode int
The hash code for this object.
no setterinherited
homepage String
final
payload PayloadKind
Shape of the downloaded artifact.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
final
versioned bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited