AppImageConfig class final

Product metadata used to stage an AppImage.

Constructors

AppImageConfig({required String name, required String displayName, required String iconPath, required List<String> categories, bool terminal = false})
const

Properties

categories List<String>
final
displayName String
final
hashCode int
The hash code for this object.
no setterinherited
iconPath String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminal bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited