LinuxPackageFormat enum
Distribution package format understood by the packager.
Values
- deb → const LinuxPackageFormat
-
Debian package, consumed by
aptanddpkg.const LinuxPackageFormat('deb') - rpm → const LinuxPackageFormat
-
RPM package, consumed by
dnf,yum, andzypper.const LinuxPackageFormat('rpm')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - packagerName → String
-
Name nfpm uses for this packager.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
String value) → LinuxPackageFormat - Parses a format name, rejecting anything unsupported.
Constants
-
values
→ const List<
LinuxPackageFormat> - A constant List of the values in this enum, in order of their declaration.