LinuxPackagingService class final

Context-bound Linux packaging API.

Constructors

LinuxPackagingService(ShipworldContext context)
const

Properties

context ShipworldContext
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build({required String repoRoot, required ArtifactPayload payload, required AppImageConfig config, required String outputPath, required String arch, required String appImageToolPath}) Future<void>
buildPackage({required String repoRoot, required ArtifactPayload payload, required LinuxPackageConfig config, required LinuxPackageFormat format, required String outputPath, required String nfpmToolPath}) Future<String>
Builds a deb or rpm from a prebuilt payload.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited