MacosPackagingService class final
Context-bound macOS signing and archive API.
Constructors
- MacosPackagingService(ShipworldContext context)
-
const
Properties
- context → ShipworldContext
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
archive(
{required String appPath, required String outputPath}) → Future< String> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sign(
MacosSignConfig config) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited