MacosSignConfig class final

Product-neutral macOS signing inputs.

Constructors

MacosSignConfig({required String inputPath, required String entitlementsPath, bool skipNotarize = false, bool isAppBundle = false, Map<String, String>? environment})
const

Properties

entitlementsPath String
final
environment Map<String, String>?
final
hashCode int
The hash code for this object.
no setterinherited
inputPath String
final
isAppBundle bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipNotarize bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited