release library

Release preparation, finalization, and version-file support.

Classes

FinalizedReleaseSet
Result of creating one or more signed tags at a verified remote HEAD.
PreparedReleaseSet
Result of an atomic release preparation.
PreparedReleaseTarget
One target included in a prepared release set.
ReleaseService
Release orchestration using immutable injected external boundaries.
Version

Enums

ReleaseType
Semver bump type accepted by the release command.

Functions

bumpVersion(Version version, ReleaseType releaseType) Version
formatVersion(Version version) String
formatVersionTag(Version version) String
parseReleaseType(String input) ReleaseType
parseVersion(String version) Version
parseVersionTag(String tag) Version
readPubspecVersion(String filePath) Future<String>
Reads the version field from a pubspec.yaml file.
readVersionConstant(String filePath, {String constant = 'packageVersion'}) Future<String>
Reads the packageVersion constant from a generated version.g.dart.
renderPubspecVersion(String content, String version) String
Renders a pubspec with its version updated while preserving other content.
renderVersionConstant(String version, {String constant = 'packageVersion'}) String
Renders the generated version.g.dart contents for version.
writePubspecVersion(String filePath, String version) Future<void>
Writes the version field to a pubspec.yaml file, preserving all other content (including comments and formatting).
writeVersionConstant(String filePath, String version, {String constant = 'packageVersion'}) Future<void>
Regenerates a version.g.dart file for version.