PreparedReleaseSet class final

Result of an atomic release preparation.

Constructors

PreparedReleaseSet({required bool dryRun, required List<PreparedReleaseTarget> targets, required String commitMessage})
const

Properties

commitMessage String
final
dryRun bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targets List<PreparedReleaseTarget>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited