PreparedReleaseTarget class final

One target included in a prepared release set.

Constructors

PreparedReleaseTarget({required String name, required String previousVersion, required String version, required String tag})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
previousVersion String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
final
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited