ShipworldTargetKind enum
Supported release target kinds.
Values
- pubPackage → const ShipworldTargetKind
-
const ShipworldTargetKind('pub-package') - cliApplication → const ShipworldTargetKind
-
const ShipworldTargetKind('cli-application') - flutterApplication → const ShipworldTargetKind
-
const ShipworldTargetKind('flutter-application')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- yamlName → String
-
Name used in
shipworld.yaml.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
String value) → ShipworldTargetKind
Constants
-
values
→ const List<
ShipworldTargetKind> - A constant List of the values in this enum, in order of their declaration.