VersionConfig class final

Version source and synchronized writer configuration.

Constructors

VersionConfig({required String pubspecPath, List<SynchronizedVersionConfig> synchronized = const []})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
pubspecPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
synchronized List<SynchronizedVersionConfig>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited