MsixIdentity class

Constructors

MsixIdentity({required String identityName, required String publisher, required String publisherDisplayName, String? displayName})
const

Properties

displayName String?
final
hashCode int
The hash code for this object.
no setterinherited
identityName String
final
publisher String
final
publisherDisplayName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited