WindowsPackagingService class final
Context-bound Windows packaging API used by applications and the CLI.
Constructors
- WindowsPackagingService(ShipworldContext context)
-
const
Properties
- context → ShipworldContext
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildBundle(
{required String repoRoot, required String version, required String packageDir, required String outputPath, required String workingDirectory}) → Future< String> -
buildPackage(
{required String arch, required ArtifactPayload payload, required MsixConfig config, required MsixIdentity identity, required String version, required String repoRoot, required String outputPath, required String packageRoot}) → Future< ({String outputPath, String packageRoot})> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited