LinuxIconAsset class final

One installed icon in the hicolor theme.

Constructors

LinuxIconAsset({required int size, required String sourcePath})
Creates an icon asset. A size of zero installs a scalable icon.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
Square pixel size, or zero for a scalable icon.
final
sourcePath String
Absolute path of the source image.
final
themeDirectory String
Directory under hicolor this icon installs into.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited