FinalizedReleaseSet class final

Result of creating one or more signed tags at a verified remote HEAD.

Constructors

FinalizedReleaseSet({required List<String> tags, required String head, required bool pushed})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
final
pushed bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited