ShipworldConfig class final
Parsed schema-v1 root configuration.
Constructors
-
ShipworldConfig({required String path, required String remote, required String batchCommitTemplate, required Map<
String, ReleaseTargetConfig> targets}) -
const
Properties
- batchCommitTemplate → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String
-
final
- remote → String
-
final
- repoRoot → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
targets
→ Map<
String, ReleaseTargetConfig> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
renderBatchCommit(
Iterable< ({String name, String version})> values) → String -
target(
String name) → ReleaseTargetConfig -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- supportedSchema → const int