ShipworldContext class final
Immutable external boundaries used by Shipworld operations.
Constructors
-
ShipworldContext({GitClient git = const IoGitClient(), ProcessExecutor process = const IoProcessExecutor(), Map<
String, String> environment = const {}, ShipworldLogger logger = const SilentShipworldLogger()}) -
const
- ShipworldContext.io({ShipworldLogger? logger})
-
Creates a context backed by the current process environment.
factory
Properties
-
environment
→ Map<
String, String> -
Environment visible to credential and tool resolution.
final
- git → GitClient
-
Git implementation used by release operations.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logger → ShipworldLogger
-
Progress sink.
final
- process → ProcessExecutor
-
Child-process implementation used by packaging operations.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run<
T> (Future< T> operation()) → Future<T> - Runs an operation with this context scoped to the current async zone.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited