MsixConfig class final
Product metadata used to render and build an MSIX package.
Constructors
- MsixConfig({required String applicationId, required String displayName, required String description, required String executableName, String defaultLanguage = 'en-US', String minWindowsVersion = '10.0.19041.0', String maxTestedWindowsVersion = '10.0.26100.0', String backgroundColor = '#102A43'})
-
const
Properties
- applicationId → String
-
final
- backgroundColor → String
-
final
- defaultLanguage → String
-
final
- description → String
-
final
- displayName → String
-
final
- executableName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxTestedWindowsVersion → String
-
final
- minWindowsVersion → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited